# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_whiteboard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from ydb.core.protos import tracing_pb2 as ydb_dot_core_dot_protos_dot_tracing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/node_whiteboard.proto\x12\x11NKikimrWhiteboard\x1a,library/cpp/actors/protos/interconnect.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a&ydb/core/protos/blobstorage_disk.proto\x1a google/protobuf/descriptor.proto\x1a\x1dydb/core/protos/tracing.proto\"4\n\x16TCustomTabletAttribute\x12\x0b\n\x03Key\x18\x01 \x01(\r\x12\r\n\x05Value\x18\x02 \x01(\t\"\x99\x06\n\x10TTabletStateInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12?\n\x05State\x18\x04 \x01(\x0e\x32\x30.NKikimrWhiteboard.TTabletStateInfo.ETabletState\x12\x11\n\tUserState\x18\x05 \x01(\r\x12\x12\n\nGeneration\x18\x06 \x01(\r\x12\x33\n\x04Type\x18\x07 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x0c\n\x04Host\x18\x08 \x01(\t\x12\x17\n\x0f\x43hannelGroupIDs\x18\t \x03(\r\x12=\n\nAttributes\x18\n \x03(\x0b\x32).NKikimrWhiteboard.TCustomTabletAttribute\x12\x0e\n\x06NodeId\x18\x0b \x01(\r\x12\x0e\n\x06Leader\x18\x0c \x01(\x08\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x12\n\nFollowerId\x18\x0e \x01(\r\x12)\n\x07Overall\x18\x0f \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12/\n\x08TenantId\x18\x10 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x0e\n\x06HiveId\x18\x11 \x01(\x06\"\x98\x02\n\x0c\x45TabletState\x12\x0b\n\x07\x43reated\x10\x00\x12\x17\n\x13ResolveStateStorage\x10\x01\x12\r\n\tCandidate\x10\x02\x12\x14\n\x10\x42lockBlobStorage\x10\x03\x12\x10\n\x0cRebuildGraph\x10\x04\x12\x12\n\x0eWriteZeroEntry\x10\x05\x12\x0c\n\x08Restored\x10\x06\x12\x0c\n\x08\x44iscover\x10\x07\x12\x08\n\x04Lock\x10\x08\x12\x08\n\x04\x44\x65\x61\x64\x10\t\x12\n\n\x06\x41\x63tive\x10\n\x12\x11\n\rResolveLeader\x10\x0b\x12\x0b\n\x07\x44\x65leted\x10\x0c\x12\x0b\n\x07Stopped\x10\r\x12\x0e\n\nReserved14\x10\x0e\x12\x0e\n\nReserved15\x10\x0f\x12\x0e\n\nReserved16\x10\x10\"f\n\x15TEvTabletStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\x12\x0e\n\x06\x46ormat\x18\x05 \x01(\t\x12\x0f\n\x07GroupBy\x18\x14 \x01(\t\x12\x16\n\x0e\x46ilterTabletId\x18\x16 \x03(\x06\"\xb0\x01\n\x16TEvTabletStateResponse\x12<\n\x0fTabletStateInfo\x18\x01 \x03(\x0b\x32#.NKikimrWhiteboard.TTabletStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\x04\x12\x17\n\x0fProcessDuration\x18\x04 \x01(\x04\x12\x0f\n\x07Packed5\x18\x05 \x01(\x0c\"\xba\x01\n\x0eTNodeStateInfo\x12\x10\n\x08PeerName\x18\x01 \x01(\t\x12\x11\n\tConnected\x18\x02 \x01(\x08\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\x12\x12\n\nChangeTime\x18\x04 \x01(\x04\x12\x1f\n\x0fOutputQueueSize\x18\x05 \x01(\rB\x06\xc8\xb9\"\x80\x80@\x12/\n\rConnectStatus\x18\x06 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\r\n\x05\x43ount\x18\r \x01(\r\"+\n\x13TEvNodeStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x80\x01\n\x14TEvNodeStateResponse\x12\x38\n\rNodeStateInfo\x18\x01 \x03(\x0b\x32!.NKikimrWhiteboard.TNodeStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xc0\x03\n\x0fTPDiskStateInfo\x12\x0f\n\x07PDiskId\x18\x01 \x01(\r\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x0c\n\x04Guid\x18\x05 \x01(\x04\x12\x10\n\x08\x43\x61tegory\x18\x06 \x01(\x04\x12\x1e\n\rAvailableSize\x18\x07 \x01(\x04\x42\x07\xc8\xb9\"\x80\x80\x80\x32\x12\x11\n\tTotalSize\x18\x08 \x01(\x04\x12\x30\n\x05State\x18\t \x01(\x0e\x32!.NKikimrBlobStorage.TPDiskState.E\x12\x0e\n\x06NodeId\x18\n \x01(\r\x12\r\n\x05\x43ount\x18\r \x01(\r\x12(\n\x06\x44\x65vice\x18\x0e \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12*\n\x08Realtime\x18\x0f \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12+\n\tStateFlag\x18\x10 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12)\n\x07Overall\x18\x11 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x14\n\x0cSerialNumber\x18\x12 \x01(\t\",\n\x14TEvPDiskStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x83\x01\n\x15TEvPDiskStateResponse\x12:\n\x0ePDiskStateInfo\x18\x01 \x03(\x0b\x32\".NKikimrWhiteboard.TPDiskStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xec\x01\n\x16TVDiskSatisfactionRank\x12\x42\n\tFreshRank\x18\x01 \x01(\x0b\x32/.NKikimrWhiteboard.TVDiskSatisfactionRank.TRank\x12\x42\n\tLevelRank\x18\x02 \x01(\x0b\x32/.NKikimrWhiteboard.TVDiskSatisfactionRank.TRank\x1aJ\n\x05TRank\x12\x19\n\x0bRankPercent\x18\x01 \x01(\rB\x04\xc8\xb9\"\x03\x12&\n\x04\x46lag\x18\x02 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\"\x9f\x07\n\x0fTVDiskStateInfo\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x04 \x01(\r\x12\x13\n\x0bVDiskSlotId\x18\x05 \x01(\r\x12\x0c\n\x04Guid\x18\x06 \x01(\x04\x12\x0c\n\x04Kind\x18\x07 \x01(\x04\x12\x0e\n\x06NodeId\x18\t \x01(\r\x12\r\n\x05\x43ount\x18\x11 \x01(\r\x12)\n\x07Overall\x18\n \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x32\n\nVDiskState\x18\x0b \x01(\x0e\x32\x1e.NKikimrWhiteboard.EVDiskState\x12+\n\tDiskSpace\x18\x0c \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x43\n\x10SatisfactionRank\x18\r \x01(\x0b\x32).NKikimrWhiteboard.TVDiskSatisfactionRank\x12\x12\n\nReplicated\x18\x0e \x01(\x08\x12#\n\x14UnreplicatedPhantoms\x18\x14 \x01(\x08:\x05\x66\x61lse\x12&\n\x17UnreplicatedNonPhantoms\x18\x15 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13ReplicationProgress\x18\x1e \x01(\x02\x12#\n\x1bReplicationSecondsRemaining\x18\x1f \x01(\r\x12\x19\n\x0eUnsyncedVDisks\x18\x0f \x01(\x04:\x01\x30\x12\x1f\n\rAllocatedSize\x18\x10 \x01(\x04\x42\x08\xc8\xb9\"\x80\x80\x80\x80\x02\x12\x1f\n\rAvailableSize\x18\x1c \x01(\x04\x42\x08\xc8\xb9\"\x80\x80\x80\x80\x02\x12\x1a\n\x12HasUnreadableBlobs\x18\x18 \x01(\x08\x12\x17\n\x0fIncarnationGuid\x18\x19 \x01(\x06\x12\x11\n\tDonorMode\x18\x1a \x01(\x08\x12\x14\n\x0cInstanceGuid\x18\x1b \x01(\x06\x12,\n\x06\x44onors\x18\x1d \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x0b\x46rontQueues\x18\x12 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x17\n\x0fStoragePoolName\x18\x13 \x01(\t\x12\x16\n\x0eReadThroughput\x18\x16 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x17 \x01(\x04\",\n\x14TEvVDiskStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x83\x01\n\x15TEvVDiskStateResponse\x12:\n\x0eVDiskStateInfo\x18\x01 \x03(\x0b\x32\".NKikimrWhiteboard.TVDiskStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xc2\x03\n\x11TBSGroupStateInfo\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x02 \x01(\t\x12.\n\x08VDiskIds\x18\x03 \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x12\n\nChangeTime\x18\x04 \x01(\x04\x12\x0e\n\x06NodeId\x18\x05 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x06 \x01(\r\x12)\n\x07Overall\x18\x07 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12)\n\x07Latency\x18\x08 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x17\n\x0fStoragePoolName\x18\x0e \x01(\t\x12\x1e\n\rAllocatedSize\x18\x0f \x01(\x04\x42\x07\xc8\xb9\"\x80\xc2\xd7/\x12\x1e\n\rAvailableSize\x18\x10 \x01(\x04\x42\x07\xc8\xb9\"\x80\xc2\xd7/\x12\x16\n\x0eReadThroughput\x18\x11 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x12 \x01(\x04\x12\x12\n\nEncryption\x18\x13 \x01(\x08\x12\x14\n\x0cVDiskNodeIds\x18\x14 \x03(\r\".\n\x16TEvBSGroupStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x89\x01\n\x17TEvBSGroupStateResponse\x12>\n\x10\x42SGroupStateInfo\x18\x01 \x03(\x0b\x32$.NKikimrWhiteboard.TBSGroupStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xb8\x08\n\x10TSystemStateInfo\x12\x11\n\tStartTime\x18\x01 \x01(\x04\x12\x12\n\nChangeTime\x18\x02 \x01(\x04\x12O\n\x0eSystemLocation\x18\x03 \x01(\x0b\x32\x37.NKikimrWhiteboard.TSystemStateInfo.TLegacyNodeLocation\x12\x13\n\x0bLoadAverage\x18\x04 \x03(\x01\x12\x14\n\x0cNumberOfCpus\x18\x05 \x01(\r\x12-\n\x0bSystemState\x18\x06 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x31\n\x0fMessageBusState\x18\x07 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12+\n\tGRpcState\x18\x08 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x0e\n\x06NodeId\x18\t \x01(\r\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x14\n\x0c\x44\x61taCenterId\x18\x0e \x01(\r\x12\x1d\n\x15\x44\x61taCenterDescription\x18\x0f \x01(\t\x12\x12\n\nDataCenter\x18\x10 \x01(\t\x12\x0e\n\x06RackId\x18\x11 \x01(\r\x12\x0c\n\x04Rack\x18\x12 \x01(\t\x12\x0c\n\x04Host\x18\x13 \x01(\t\x12\x0f\n\x07Version\x18\x14 \x01(\t\x12\x41\n\tPoolStats\x18\x15 \x03(\x0b\x32..NKikimrWhiteboard.TSystemStateInfo.TPoolStats\x12@\n\tEndpoints\x18\x16 \x03(\x0b\x32-.NKikimrWhiteboard.TSystemStateInfo.TEndpoint\x12\r\n\x05Roles\x18\x17 \x03(\t\x12\x0f\n\x07Tenants\x18\x18 \x03(\t\x12\x13\n\x0b\x43lusterName\x18\x19 \x01(\t\x12\x12\n\nMemoryUsed\x18\x1a \x01(\x04\x12\x13\n\x0bMemoryLimit\x18\x1b \x01(\x04\x12@\n\x0b\x43onfigState\x18\x1c \x01(\x0e\x32\x1f.NKikimrWhiteboard.EConfigState:\nConsistent\x12\x19\n\x11MemoryUsedInAlloc\x18\x1d \x01(\x04\x12\x14\n\x0cMaxDiskUsage\x18\x1e \x01(\x01\x12\x34\n\x08Location\x18\x1f \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x1a@\n\nTPoolStats\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x05Usage\x18\x02 \x01(\x01\x42\x04\xd0\xb9\"\x1e\x12\x0f\n\x07Threads\x18\x03 \x01(\r\x1a*\n\tTEndpoint\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x1aS\n\x13TLegacyNodeLocation\x12\x12\n\nDataCenter\x18\x01 \x01(\r\x12\x0c\n\x04Room\x18\x02 \x01(\r\x12\x0c\n\x04Rack\x18\x03 \x01(\r\x12\x0c\n\x04\x42ody\x18\x04 \x01(\r\"-\n\x15TEvSystemStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x86\x01\n\x16TEvSystemStateResponse\x12<\n\x0fSystemStateInfo\x18\x01 \x03(\x0b\x32#.NKikimrWhiteboard.TSystemStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\x18\n\x16TEvTabletLookupRequest\",\n\x17TEvTabletLookupResponse\x12\x11\n\tTabletIDs\x18\x01 \x03(\x04\")\n\x15TEvTraceLookupRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\"D\n\x16TEvTraceLookupResponse\x12*\n\x08TraceIDs\x18\x01 \x03(\x0b\x32\x18.NKikimrTracing.TTraceID\"o\n\x0fTEvTraceRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12)\n\x07TraceID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x0c\n\x04Mode\x18\x03 \x01(\r\x12\x11\n\tPrecision\x18\x04 \x01(\r\"!\n\x10TEvTraceResponse\x12\r\n\x05Trace\x18\x01 \x01(\t\"\x86\x01\n\x14TEvSignalBodyRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12)\n\x07TraceID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x0c\n\x04Mode\x18\x03 \x01(\r\x12\x11\n\tPrecision\x18\x04 \x01(\r\x12\x10\n\x08SignalID\x18\x05 \x01(\t\"+\n\x15TEvSignalBodyResponse\x12\x12\n\nSignalBody\x18\x01 \x01(\t*=\n\x05\x45\x46lag\x12\x08\n\x04Grey\x10\x00\x12\t\n\x05Green\x10\x01\x12\n\n\x06Yellow\x10\x02\x12\n\n\x06Orange\x10\x03\x12\x07\n\x03Red\x10\x04*{\n\x0b\x45VDiskState\x12\x0b\n\x07Initial\x10\x01\x12\x16\n\x12LocalRecoveryError\x10\x02\x12\x14\n\x10SyncGuidRecovery\x10\x03\x12\x19\n\x15SyncGuidRecoveryError\x10\x04\x12\x06\n\x02OK\x10\x05\x12\x0e\n\nPDiskError\x10\x06*,\n\x0c\x45\x43onfigState\x12\x0e\n\nConsistent\x10\x00\x12\x0c\n\x08Outdated\x10\x01:B\n\x19InsignificantChangeAmount\x12\x1d.google.protobuf.FieldOptions\x18\x99\xa7\x04 \x01(\x04:C\n\x1aInsignificantChangePercent\x12\x1d.google.protobuf.FieldOptions\x18\x9a\xa7\x04 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_whiteboard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(InsignificantChangeAmount)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(InsignificantChangePercent)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODESTATEINFO.fields_by_name['OutputQueueSize']._options = None
  _TNODESTATEINFO.fields_by_name['OutputQueueSize']._serialized_options = b'\310\271\"\200\200@'
  _TPDISKSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TPDISKSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\200\2002'
  _TVDISKSATISFACTIONRANK_TRANK.fields_by_name['RankPercent']._options = None
  _TVDISKSATISFACTIONRANK_TRANK.fields_by_name['RankPercent']._serialized_options = b'\310\271\"\003'
  _TVDISKSTATEINFO.fields_by_name['AllocatedSize']._options = None
  _TVDISKSTATEINFO.fields_by_name['AllocatedSize']._serialized_options = b'\310\271\"\200\200\200\200\002'
  _TVDISKSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TVDISKSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\200\200\200\002'
  _TBSGROUPSTATEINFO.fields_by_name['AllocatedSize']._options = None
  _TBSGROUPSTATEINFO.fields_by_name['AllocatedSize']._serialized_options = b'\310\271\"\200\302\327/'
  _TBSGROUPSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TBSGROUPSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\302\327/'
  _TSYSTEMSTATEINFO_TPOOLSTATS.fields_by_name['Usage']._options = None
  _TSYSTEMSTATEINFO_TPOOLSTATS.fields_by_name['Usage']._serialized_options = b'\320\271\"\036'
  _EFLAG._serialized_start=6176
  _EFLAG._serialized_end=6237
  _EVDISKSTATE._serialized_start=6239
  _EVDISKSTATE._serialized_end=6362
  _ECONFIGSTATE._serialized_start=6364
  _ECONFIGSTATE._serialized_end=6408
  _TCUSTOMTABLETATTRIBUTE._serialized_start=275
  _TCUSTOMTABLETATTRIBUTE._serialized_end=327
  _TTABLETSTATEINFO._serialized_start=330
  _TTABLETSTATEINFO._serialized_end=1123
  _TTABLETSTATEINFO_ETABLETSTATE._serialized_start=843
  _TTABLETSTATEINFO_ETABLETSTATE._serialized_end=1123
  _TEVTABLETSTATEREQUEST._serialized_start=1125
  _TEVTABLETSTATEREQUEST._serialized_end=1227
  _TEVTABLETSTATERESPONSE._serialized_start=1230
  _TEVTABLETSTATERESPONSE._serialized_end=1406
  _TNODESTATEINFO._serialized_start=1409
  _TNODESTATEINFO._serialized_end=1595
  _TEVNODESTATEREQUEST._serialized_start=1597
  _TEVNODESTATEREQUEST._serialized_end=1640
  _TEVNODESTATERESPONSE._serialized_start=1643
  _TEVNODESTATERESPONSE._serialized_end=1771
  _TPDISKSTATEINFO._serialized_start=1774
  _TPDISKSTATEINFO._serialized_end=2222
  _TEVPDISKSTATEREQUEST._serialized_start=2224
  _TEVPDISKSTATEREQUEST._serialized_end=2268
  _TEVPDISKSTATERESPONSE._serialized_start=2271
  _TEVPDISKSTATERESPONSE._serialized_end=2402
  _TVDISKSATISFACTIONRANK._serialized_start=2405
  _TVDISKSATISFACTIONRANK._serialized_end=2641
  _TVDISKSATISFACTIONRANK_TRANK._serialized_start=2567
  _TVDISKSATISFACTIONRANK_TRANK._serialized_end=2641
  _TVDISKSTATEINFO._serialized_start=2644
  _TVDISKSTATEINFO._serialized_end=3571
  _TEVVDISKSTATEREQUEST._serialized_start=3573
  _TEVVDISKSTATEREQUEST._serialized_end=3617
  _TEVVDISKSTATERESPONSE._serialized_start=3620
  _TEVVDISKSTATERESPONSE._serialized_end=3751
  _TBSGROUPSTATEINFO._serialized_start=3754
  _TBSGROUPSTATEINFO._serialized_end=4204
  _TEVBSGROUPSTATEREQUEST._serialized_start=4206
  _TEVBSGROUPSTATEREQUEST._serialized_end=4252
  _TEVBSGROUPSTATERESPONSE._serialized_start=4255
  _TEVBSGROUPSTATERESPONSE._serialized_end=4392
  _TSYSTEMSTATEINFO._serialized_start=4395
  _TSYSTEMSTATEINFO._serialized_end=5475
  _TSYSTEMSTATEINFO_TPOOLSTATS._serialized_start=5282
  _TSYSTEMSTATEINFO_TPOOLSTATS._serialized_end=5346
  _TSYSTEMSTATEINFO_TENDPOINT._serialized_start=5348
  _TSYSTEMSTATEINFO_TENDPOINT._serialized_end=5390
  _TSYSTEMSTATEINFO_TLEGACYNODELOCATION._serialized_start=5392
  _TSYSTEMSTATEINFO_TLEGACYNODELOCATION._serialized_end=5475
  _TEVSYSTEMSTATEREQUEST._serialized_start=5477
  _TEVSYSTEMSTATEREQUEST._serialized_end=5522
  _TEVSYSTEMSTATERESPONSE._serialized_start=5525
  _TEVSYSTEMSTATERESPONSE._serialized_end=5659
  _TEVTABLETLOOKUPREQUEST._serialized_start=5661
  _TEVTABLETLOOKUPREQUEST._serialized_end=5685
  _TEVTABLETLOOKUPRESPONSE._serialized_start=5687
  _TEVTABLETLOOKUPRESPONSE._serialized_end=5731
  _TEVTRACELOOKUPREQUEST._serialized_start=5733
  _TEVTRACELOOKUPREQUEST._serialized_end=5774
  _TEVTRACELOOKUPRESPONSE._serialized_start=5776
  _TEVTRACELOOKUPRESPONSE._serialized_end=5844
  _TEVTRACEREQUEST._serialized_start=5846
  _TEVTRACEREQUEST._serialized_end=5957
  _TEVTRACERESPONSE._serialized_start=5959
  _TEVTRACERESPONSE._serialized_end=5992
  _TEVSIGNALBODYREQUEST._serialized_start=5995
  _TEVSIGNALBODYREQUEST._serialized_end=6129
  _TEVSIGNALBODYRESPONSE._serialized_start=6131
  _TEVSIGNALBODYRESPONSE._serialized_end=6174
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/yq/libs/config/protos/common.proto\x12\x0bNYq.NConfig\"`\n\x10TYdbDriverConfig\x12\x19\n\x11NetworkThreadsNum\x18\x01 \x01(\x04\x12\x18\n\x10\x43lientThreadsNum\x18\x02 \x01(\x04\x12\x17\n\x0fGrpcMemoryQuota\x18\x03 \x01(\x04\"\xea\x02\n\rTCommonConfig\x12\x36\n\x0fYdbDriverConfig\x18\x01 \x01(\x0b\x32\x1d.NYq.NConfig.TYdbDriverConfig\x12\x1b\n\x13YdbMvpCloudEndpoint\x18\x02 \x01(\t\x12\x12\n\nMdbGateway\x18\x03 \x01(\t\x12\x17\n\x0fUseBearerForYdb\x18\x04 \x01(\x08\x12\x18\n\x10MdbTransformHost\x18\x05 \x01(\x08\x12\x1d\n\x15ObjectStorageEndpoint\x18\x06 \x01(\t\x12\x11\n\tIdsPrefix\x18\x07 \x01(\t\x12\x1c\n\x14MaxTasksPerOperation\x18\x08 \x01(\x04\x12\'\n\x1fQueryArtifactsCompressionMethod\x18\t \x01(\t\x12(\n QueryArtifactsCompressionMinSize\x18\n \x01(\x04\x12\x1a\n\x12MonitoringEndpoint\x18\x0b \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TYDBDRIVERCONFIG._serialized_start=60
  _TYDBDRIVERCONFIG._serialized_end=156
  _TCOMMONCONFIG._serialized_start=159
  _TCOMMONCONFIG._serialized_end=521
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/replication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/replication.proto\x12\x12NKikimrReplication\x1a\x1aydb/core/protos/base.proto\"4\n\x12TStaticCredentials\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\"\x87\x04\n\x12TReplicationConfig\x12\x13\n\x0bSrcEndpoint\x18\x01 \x01(\t\x12\x13\n\x0bSrcDatabase\x18\x02 \x01(\t\x12\x43\n\x11StaticCredentials\x18\x03 \x01(\x0b\x32&.NKikimrReplication.TStaticCredentialsH\x00\x12N\n\nEverything\x18\x04 \x01(\x0b\x32\x38.NKikimrReplication.TReplicationConfig.TTargetEverythingH\x01\x12J\n\x08Specific\x18\x05 \x01(\x0b\x32\x36.NKikimrReplication.TReplicationConfig.TTargetSpecificH\x01\x12\x13\n\x0bInitialSync\x18\x06 \x01(\x08\x1a&\n\x11TTargetEverything\x12\x11\n\tDstPrefix\x18\x01 \x01(\t\x1a\x8f\x01\n\x0fTTargetSpecific\x12O\n\x07Targets\x18\x01 \x03(\x0b\x32>.NKikimrReplication.TReplicationConfig.TTargetSpecific.TTarget\x1a+\n\x07TTarget\x12\x0f\n\x07SrcPath\x18\x01 \x01(\t\x12\x0f\n\x07\x44stPath\x18\x02 \x01(\tB\r\n\x0b\x43redentialsB\x08\n\x06Target\",\n\x0cTOperationId\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06PartId\x18\x02 \x01(\r\"\xac\x01\n\x14TEvCreateReplication\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x35\n\x0bOperationId\x18\x02 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x36\n\x06\x43onfig\x18\x03 \x01(\x0b\x32&.NKikimrReplication.TReplicationConfig\"\xe4\x01\n\x1aTEvCreateReplicationResult\x12\x35\n\x0bOperationId\x18\x01 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x46\n\x06Status\x18\x03 \x01(\x0e\x32\x36.NKikimrReplication.TEvCreateReplicationResult.EStatus\"7\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x02\"r\n\x12TEvDropReplication\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x35\n\x0bOperationId\x18\x02 \x01(\x0b\x32 .NKikimrReplication.TOperationId\"\xdb\x01\n\x18TEvDropReplicationResult\x12\x35\n\x0bOperationId\x18\x01 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x44\n\x06Status\x18\x03 \x01(\x0e\x32\x34.NKikimrReplication.TEvDropReplicationResult.EStatus\"2\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.replication_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTATICCREDENTIALS._serialized_start=85
  _TSTATICCREDENTIALS._serialized_end=137
  _TREPLICATIONCONFIG._serialized_start=140
  _TREPLICATIONCONFIG._serialized_end=659
  _TREPLICATIONCONFIG_TTARGETEVERYTHING._serialized_start=450
  _TREPLICATIONCONFIG_TTARGETEVERYTHING._serialized_end=488
  _TREPLICATIONCONFIG_TTARGETSPECIFIC._serialized_start=491
  _TREPLICATIONCONFIG_TTARGETSPECIFIC._serialized_end=634
  _TREPLICATIONCONFIG_TTARGETSPECIFIC_TTARGET._serialized_start=591
  _TREPLICATIONCONFIG_TTARGETSPECIFIC_TTARGET._serialized_end=634
  _TOPERATIONID._serialized_start=661
  _TOPERATIONID._serialized_end=705
  _TEVCREATEREPLICATION._serialized_start=708
  _TEVCREATEREPLICATION._serialized_end=880
  _TEVCREATEREPLICATIONRESULT._serialized_start=883
  _TEVCREATEREPLICATIONRESULT._serialized_end=1111
  _TEVCREATEREPLICATIONRESULT_ESTATUS._serialized_start=1056
  _TEVCREATEREPLICATIONRESULT_ESTATUS._serialized_end=1111
  _TEVDROPREPLICATION._serialized_start=1113
  _TEVDROPREPLICATION._serialized_end=1227
  _TEVDROPREPLICATIONRESULT._serialized_start=1230
  _TEVDROPREPLICATIONRESULT._serialized_end=1449
  _TEVDROPREPLICATIONRESULT_ESTATUS._serialized_start=1399
  _TEVDROPREPLICATIONRESULT_ESTATUS._serialized_end=1449
# @@protoc_insertion_point(module_scope)



import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
import sys
from collections import defaultdict

description = 'Add groups to the pool'


def add_options(p):
    p.add_argument('--pool-name', type=str, required=True, help='Storage pool to add to')
    p.add_argument('--groups', type=int, required=True, help='Number of groups to add')
    table.TableOutput([]).add_options(p)


def create_request(args, storage_pool):
    request = common.kikimr_bsconfig.TConfigRequest(Rollback=args.dry_run)
    cmd = request.Command.add()
    cmd.DefineStoragePool.CopyFrom(storage_pool)
    cmd.DefineStoragePool.ClearField("Geometry")
    cmd.DefineStoragePool.NumGroups += args.groups
    cmd = request.Command.add()
    cmd.QueryBaseConfig.CopyFrom(common.kikimr_bsconfig.TQueryBaseConfig())
    return request


def perform_request(request):
    return common.invoke_bsc_request(request)


def is_successful_response(response):
    return common.is_successful_bsc_response(response)


def do(args):
    columns = [
        'BoxId:PoolId',
        'PoolName',
        'Affected PDisks',
        'Static slots on PDisk',
        'VSlots on PDisk before',
        'VSlots on PDisk after',
        'Result',
    ]

    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
    base_config = base_config_and_storage_pools['BaseConfig']
    storage_pools = base_config_and_storage_pools['StoragePools']

    sp = None
    for p in storage_pools:
        if p.Name == args.pool_name:
            if sp is not None:
                common.print_status(args, success=False, error_reason='Storage pool name %s is not unique' % args.pool_name)
                sys.exit(1)
            sp = p

    if sp is None:
        common.print_status(args, success=False, error_reason="Couldn't find storage pool with name %s" % args.pool_name)
        sys.exit(1)

    request = create_request(args, sp)
    response = perform_request(request)
    if not is_successful_response(response):
        common.print_request_result(args, request, response)
        sys.exit(1)

    pdisk_usage_before = common.build_pdisk_usage_map(base_config, count_donors=False, storage_pool=sp)
    pdisk_usage_after = common.build_pdisk_usage_map(response.Status[1].BaseConfig, count_donors=False, storage_pool=sp)

    keys = set(pdisk_usage_before) | set(pdisk_usage_after)
    changes = defaultdict(int)

    pdisk_static_slots_map = common.build_pdisk_static_slots_map(base_config)

    for pdisk_id in keys:
        changes[pdisk_usage_before.get(pdisk_id, 0), pdisk_usage_after.get(pdisk_id, 0), pdisk_static_slots_map.get(pdisk_id, 0)] += 1

    table_output = table.TableOutput(columns, default_visible_columns=columns)

    rows = []
    for (before, after, static), num in sorted(changes.items(), key=lambda x: changes[x[0]], reverse=True):
        row = {}
        row['BoxId:PoolId'] = '[%u:%u]' % (sp.BoxId, sp.StoragePoolId)
        row['PoolName'] = sp.Name
        row['Affected PDisks'] = num
        row['Static slots on PDisk'] = static
        row['VSlots on PDisk before'] = before
        row['VSlots on PDisk after'] = after
        row['Result'] = 'unchanged' if before == after else 'increased'
        rows.append(row)

    table_output.dump(rows, args)



import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
from collections import defaultdict

description = 'List cluster'


def add_options(p):
    table.TableOutput([]).add_options(p)


def do(args):
    columns = [
        'Cluster',
        'Hosts',
        'Nodes',
        'Pools',
        'Groups',
        'VDisks',
        'Boxes',
        'PDisks',
    ]
    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()
    base_config = base_config_and_storage_pools['BaseConfig']
    storage_pools = base_config_and_storage_pools['StoragePools']

    node_fqdn_map = common.build_node_fqdn_map(base_config)

    table_output = table.TableOutput(columns, default_visible_columns=columns)

    stat = defaultdict(set)

    for node in base_config.Node:
        stat['Nodes'].add(node.NodeId)
        stat['Hosts'].add(node_fqdn_map[node.NodeId])

    for pdisk in base_config.PDisk:
        pdisk_id = common.get_pdisk_id(pdisk)
        stat['PDisks'].add(pdisk_id)

    for group in base_config.Group:
        stat['Groups'].add(group.GroupId)

    for vslot in base_config.VSlot:
        vslot_id = common.get_vslot_id(vslot.VSlotId)
        stat['VDisks'].add(vslot_id)

    for sp in storage_pools:
        stat['Boxes'].add(sp.BoxId)
        stat['Pools'].add((sp.BoxId, sp.StoragePoolId))

    row = {}

    for key in stat:
        row[key] = len(stat[key])

    table_output.dump([row], args)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/issue_id.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.public.issue.protos import issue_severity_pb2 as ydb_dot_library_dot_yql_dot_public_dot_issue_dot_protos_dot_issue__severity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/issue_id.proto\x12\rNKikimrIssues\x1a\x38ydb/library/yql/public/issue/protos/issue_severity.proto\"\xd0\x07\n\nTIssuesIds\x12/\n\x03ids\x18\x01 \x03(\x0b\x32\".NKikimrIssues.TIssuesIds.TIssueId\x1a\x80\x01\n\x08TIssueId\x12\x32\n\x04\x63ode\x18\x02 \x01(\x0e\x32$.NKikimrIssues.TIssuesIds.EIssueCode\x12\x30\n\x08severity\x18\x01 \x01(\x0e\x32\x1e.NYql.TSeverityIds.ESeverityId\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\x8d\x06\n\nEIssueCode\x12\x11\n\rDEFAULT_ERROR\x10\x00\x12\x0e\n\nUNEXPECTED\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x13\n\rACCESS_DENIED\x10\xc0\x9a\x0c\x12\x14\n\x0ePATH_NOT_EXIST\x10\x88\x9c\x0c\x12\x18\n\x12\x44\x41TABASE_NOT_EXIST\x10\x8a\x9c\x0c\x12\x1d\n\x17GENERIC_DATASHARD_ERROR\x10\xec\x9c\x0c\x12\x1b\n\x15GENERIC_RESOLVE_ERROR\x10\xd0\x9d\x0c\x12\x1a\n\x14RESOLVE_LOOKUP_ERROR\x10\xd1\x9d\x0c\x12\x1b\n\x15GENERIC_TXPROXY_ERROR\x10\xb4\x9e\x0c\x12\x15\n\x0fKEY_PARSE_ERROR\x10\xb5\x9e\x0c\x12\x14\n\x0e\x45MPTY_OP_RANGE\x10\xb6\x9e\x0c\x12\x12\n\x0c\x45NGINE_ERROR\x10\xb7\x9e\x0c\x12\x1b\n\x15\x44OMAIN_LOCALITY_ERROR\x10\xb8\x9e\x0c\x12\x19\n\x13SHARD_NOT_AVAILABLE\x10\xb9\x9e\x0c\x12\x16\n\x10TX_STATE_UNKNOWN\x10\xba\x9e\x0c\x12 \n\x1aTX_DECLINED_BY_COORDINATOR\x10\xbb\x9e\x0c\x12&\n TX_DECLINED_IMPLICIT_COORDINATOR\x10\xbc\x9e\x0c\x12!\n\x1bSHARD_PROGRAM_SIZE_EXCEEDED\x10\xbd\x9e\x0c\x12\x14\n\x0eSCOPE_REQPROXY\x10\x98\x9f\x0c\x12\x1d\n\x17SCOPE_TXPROXY_INTERPRET\x10\xfc\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_RESOLVE\x10\xfd\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_PREPARE\x10\xfe\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_EXECUTE\x10\xff\x9f\x0c\x12\x1e\n\x18YDB_API_VALIDATION_ERROR\x10\xe0\xa0\x0c\x12\x1a\n\x14YDB_AUTH_UNAVAILABLE\x10\xe1\xa0\x0c\x12\x16\n\x10YDB_DB_NOT_READY\x10\xe2\xa0\x0c\x12 \n\x1aYDB_RESOURCE_USAGE_LIMITED\x10\xe3\xa0\x0c\"\x81\x03\n\nTStatusIds\"\xf2\x02\n\x0b\x45StatusCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tTRANSIENT\x10\x02\x12\n\n\x05\x45RROR\x10\x80\x01\x12\x0f\n\nINPROGRESS\x10\x81\x01\x12\x0c\n\x07TIMEOUT\x10\x82\x01\x12\r\n\x08NOTREADY\x10\x83\x01\x12\x13\n\x0eINTERNAL_ERROR\x10\x85\x01\x12\r\n\x08REJECTED\x10\x86\x01\x12\x11\n\x0cNOTSUPPORTED\x10\x87\x01\x12\x0f\n\nOVERLOADED\x10\x88\x01\x12\x13\n\x0ePATH_NOT_EXIST\x10\x89\x01\x12\x12\n\rACCESS_DENIED\x10\x8a\x01\x12\x10\n\x0b\x42\x41\x44_REQUEST\x10\x96\x01\x12\x10\n\x0bQUERY_ERROR\x10\x97\x01\x12\x12\n\rPROCESS_ERROR\x10\x98\x01\x12\x10\n\x0b\x42\x41\x44_SESSION\x10\x99\x01\x12\x16\n\x11LOCKS_INVALIDATED\x10\xaa\x01\x12\x1a\n\x15LOCKS_ACQUIRE_FAILURE\x10\xab\x01\x12\x11\n\x0cSCHEME_ERROR\x10\xac\x01\x42\x18\n\x16ru.yandex.kikimr.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.issue_id_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TISSUESIDS._serialized_start=108
  _TISSUESIDS._serialized_end=1084
  _TISSUESIDS_TISSUEID._serialized_start=172
  _TISSUESIDS_TISSUEID._serialized_end=300
  _TISSUESIDS_EISSUECODE._serialized_start=303
  _TISSUESIDS_EISSUECODE._serialized_end=1084
  _TSTATUSIDS._serialized_start=1087
  _TSTATUSIDS._serialized_end=1472
  _TSTATUSIDS_ESTATUSCODE._serialized_start=1102
  _TSTATUSIDS_ESTATUSCODE._serialized_end=1472
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/config_units.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/config_units.proto\x12\x12NKikimrConfigUnits\"H\n\tTDuration\x12\x0f\n\x07Seconds\x18\x01 \x01(\x04\x12\x14\n\x0cMilliseconds\x18\x02 \x01(\x04\x12\x14\n\x0cMicroseconds\x18\x03 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.config_units_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDURATION._serialized_start=58
  _TDURATION._serialized_end=130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_pipe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/tablet_pipe.proto\x12\x11NKikimrTabletPipe\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\"Z\n\nTEvConnect\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x46\x65\x61tures\x18\x03 \x01(\r\"\xd9\x01\n\x10TEvConnectResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12(\n\x08\x43lientId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x14\n\x06Leader\x18\x05 \x01(\x08:\x04true\x12\x1d\n\x15SupportsDataInPayload\x18\x06 \x01(\x08\"\x98\x01\n\x07TEvPush\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12&\n\x06Sender\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x42uffer\x18\x04 \x01(\x0c\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x16\n\x0e\x45xtendedFormat\x18\x06 \x01(\x08\x12\r\n\x05SeqNo\x18\x07 \x01(\x04\"u\n\rTEvPeerClosed\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x92\x01\n\x0fTEvPeerShutdown\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x19\n\x11MaxForwardedSeqNo\x18\x04 \x01(\x04*)\n\x08\x45\x46\x65\x61ture\x12\x1d\n\x19\x46\x45\x41TURE_GRACEFUL_SHUTDOWN\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_pipe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EFEATURE._serialized_start=859
  _EFEATURE._serialized_end=900
  _TEVCONNECT._serialized_start=124
  _TEVCONNECT._serialized_end=214
  _TEVCONNECTRESULT._serialized_start=217
  _TEVCONNECTRESULT._serialized_end=434
  _TEVPUSH._serialized_start=437
  _TEVPUSH._serialized_end=589
  _TEVPEERCLOSED._serialized_start=591
  _TEVPEERCLOSED._serialized_end=708
  _TEVPEERSHUTDOWN._serialized_start=711
  _TEVPEERSHUTDOWN._serialized_end=857
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_blob_depot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ydb/core/protos/counters_blob_depot.proto\x12\x10NKikimrBlobDepot\x1a\x1eydb/core/protos/counters.proto*\x82\x02\n\x0f\x45SimpleCounters\x12=\n\x1e\x43OUNTER_TOTAL_STORED_DATA_SIZE\x10\x00\x1a\x19\x82\xd6\x1b\x15\n\x13TotalStoredDataSize\x12?\n\x1f\x43OUNTER_TOTAL_STORED_TRASH_SIZE\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14TotalStoredTrashSize\x12\x39\n\x1c\x43OUNTER_IN_FLIGHT_TRASH_SIZE\x10\x02\x1a\x17\x82\xd6\x1b\x13\n\x11InFlightTrashSize\x12\x34\n\x19\x43OUNTER_BYTES_TO_DECOMMIT\x10\x03\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42ytesToDecommit*\x8a\x02\n\x13\x45\x43umulativeCounters\x12.\n\x15\x43OUNTER_PUTS_INCOMING\x10\x00\x1a\x13\x82\xd6\x1b\x0f\n\rPuts/Incoming\x12\"\n\x0f\x43OUNTER_PUTS_OK\x10\x01\x1a\r\x82\xd6\x1b\t\n\x07Puts/Ok\x12(\n\x12\x43OUNTER_PUTS_ERROR\x10\x02\x1a\x10\x82\xd6\x1b\x0c\n\nPuts/Error\x12\x37\n\x1a\x43OUNTER_DECOMMIT_GET_BYTES\x10\x03\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65\x63ommit/GetBytes\x12<\n\x1d\x43OUNTER_DECOMMIT_PUT_OK_BYTES\x10\x04\x1a\x19\x82\xd6\x1b\x15\n\x13\x44\x65\x63ommit/PutOkBytes*\xad\x03\n\x13\x45PercentileCounters\x12\x38\n COUNTER_PERCENTILE_SELECT_GROUPS\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cSelectGroups\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\x94\x06\n\x08\x45TxTypes\x12<\n\x1bTXTYPE_PUT_ASSIMILATED_DATA\x10\x00\x1a\x1b\x8a\xd6\x1b\x17\n\x15TTxPutAssimilatedData\x12\x42\n\x1eTXTYPE_COMMIT_ASSIMILATED_BLOB\x10\x01\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxCommitAssimilatedBlob\x12\x31\n\x15TXTYPE_FINISH_COPYING\x10\x02\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxFinishCopying\x12;\n\x1aTXTYPE_FINISH_DECOMMISSION\x10\x03\x1a\x1b\x8a\xd6\x1b\x17\n\x15TTxFinishDecommission\x12%\n\x0fTXTYPE_MON_DATA\x10\x04\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxMonData\x12+\n\x12TXTYPE_INIT_SCHEMA\x10\x05\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxInitSchema\x12-\n\x13TXTYPE_APPLY_CONFIG\x10\x06\x1a\x14\x8a\xd6\x1b\x10\n\x0eTTxApplyConfig\x12\x1e\n\x0bTXTYPE_LOAD\x10\x07\x1a\r\x8a\xd6\x1b\t\n\x07TTxLoad\x12%\n\x0fTXTYPE_ISSUE_GC\x10\x08\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxIssueGC\x12)\n\x11TXTYPE_CONFIRM_GC\x10\t\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxConfirmGC\x12:\n\x1aTXTYPE_COMMIT_CERTAIN_KEYS\x10\n\x1a\x1a\x8a\xd6\x1b\x16\n\x14TTxCommitCertainKeys\x12$\n\x0eTXTYPE_RESOLVE\x10\x0b\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxResolve\x12\'\n\x10TXTYPE_DATA_LOAD\x10\x0c\x1a\x11\x8a\xd6\x1b\r\n\x0bTTxDataLoad\x12\x33\n\x16TXTYPE_COLLECT_GARBAGE\x10\r\x1a\x17\x8a\xd6\x1b\x13\n\x11TTxCollectGarbage\x12\x32\n\x16TXTYPE_COMMIT_BLOB_SEQ\x10\x0e\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxCommitBlobSeq\x12-\n\x13TXTYPE_UPDATE_BLOCK\x10\x0f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTTxUpdateBlockB\r\x9a\xd6\x1b\tBlobDepot')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_blob_depot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\232\326\033\tBlobDepot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_DATA_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_DATA_SIZE"]._serialized_options = b'\202\326\033\025\n\023TotalStoredDataSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_TRASH_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_TRASH_SIZE"]._serialized_options = b'\202\326\033\026\n\024TotalStoredTrashSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_TRASH_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_TRASH_SIZE"]._serialized_options = b'\202\326\033\023\n\021InFlightTrashSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_TO_DECOMMIT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_TO_DECOMMIT"]._serialized_options = b'\202\326\033\021\n\017BytesToDecommit'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_INCOMING"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_INCOMING"]._serialized_options = b'\202\326\033\017\n\rPuts/Incoming'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_OK"]._serialized_options = b'\202\326\033\t\n\007Puts/Ok'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_ERROR"]._serialized_options = b'\202\326\033\014\n\nPuts/Error'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_GET_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_GET_BYTES"]._serialized_options = b'\202\326\033\023\n\021Decommit/GetBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_PUT_OK_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_PUT_OK_BYTES"]._serialized_options = b'\202\326\033\025\n\023Decommit/PutOkBytes'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._serialized_options = b'\202\326\033\016\n\014SelectGroups'
  _ETXTYPES.values_by_name["TXTYPE_PUT_ASSIMILATED_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PUT_ASSIMILATED_DATA"]._serialized_options = b'\212\326\033\027\n\025TTxPutAssimilatedData'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_ASSIMILATED_BLOB"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_ASSIMILATED_BLOB"]._serialized_options = b'\212\326\033\032\n\030TTxCommitAssimilatedBlob'
  _ETXTYPES.values_by_name["TXTYPE_FINISH_COPYING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FINISH_COPYING"]._serialized_options = b'\212\326\033\022\n\020TTxFinishCopying'
  _ETXTYPES.values_by_name["TXTYPE_FINISH_DECOMMISSION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FINISH_DECOMMISSION"]._serialized_options = b'\212\326\033\027\n\025TTxFinishDecommission'
  _ETXTYPES.values_by_name["TXTYPE_MON_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DATA"]._serialized_options = b'\212\326\033\014\n\nTTxMonData'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\017\n\rTTxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CONFIG"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CONFIG"]._serialized_options = b'\212\326\033\020\n\016TTxApplyConfig'
  _ETXTYPES.values_by_name["TXTYPE_LOAD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD"]._serialized_options = b'\212\326\033\t\n\007TTxLoad'
  _ETXTYPES.values_by_name["TXTYPE_ISSUE_GC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ISSUE_GC"]._serialized_options = b'\212\326\033\014\n\nTTxIssueGC'
  _ETXTYPES.values_by_name["TXTYPE_CONFIRM_GC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIRM_GC"]._serialized_options = b'\212\326\033\016\n\014TTxConfirmGC'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_CERTAIN_KEYS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_CERTAIN_KEYS"]._serialized_options = b'\212\326\033\026\n\024TTxCommitCertainKeys'
  _ETXTYPES.values_by_name["TXTYPE_RESOLVE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESOLVE"]._serialized_options = b'\212\326\033\014\n\nTTxResolve'
  _ETXTYPES.values_by_name["TXTYPE_DATA_LOAD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DATA_LOAD"]._serialized_options = b'\212\326\033\r\n\013TTxDataLoad'
  _ETXTYPES.values_by_name["TXTYPE_COLLECT_GARBAGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLLECT_GARBAGE"]._serialized_options = b'\212\326\033\023\n\021TTxCollectGarbage'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_BLOB_SEQ"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_BLOB_SEQ"]._serialized_options = b'\212\326\033\022\n\020TTxCommitBlobSeq'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_BLOCK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_BLOCK"]._serialized_options = b'\212\326\033\020\n\016TTxUpdateBlock'
  _ESIMPLECOUNTERS._serialized_start=96
  _ESIMPLECOUNTERS._serialized_end=354
  _ECUMULATIVECOUNTERS._serialized_start=357
  _ECUMULATIVECOUNTERS._serialized_end=623
  _EPERCENTILECOUNTERS._serialized_start=626
  _EPERCENTILECOUNTERS._serialized_end=1055
  _ETXTYPES._serialized_start=1058
  _ETXTYPES._serialized_end=1846
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/netclassifier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/netclassifier.proto\x12\x14NKikimrNetClassifier\"\xff\x01\n\x1bTNetClassifierUpdaterConfig\x12\x18\n\x10NetDataSourceUrl\x18\x01 \x01(\t\x12\x1c\n\x14RetryIntervalSeconds\x18\x02 \x01(\r\x12$\n\x1cNetDataUpdateIntervalSeconds\x18\x03 \x01(\r\x12N\n\x06\x46ormat\x18\x04 \x01(\x0e\x32\x39.NKikimrNetClassifier.TNetClassifierUpdaterConfig.EFormat:\x03TSV\x12\x12\n\nNetBoxTags\x18\x05 \x03(\t\"\x1e\n\x07\x45\x46ormat\x12\x07\n\x03TSV\x10\x00\x12\n\n\x06NETBOX\x10\x01\"&\n\x07TSubnet\x12\x0c\n\x04Mask\x18\x01 \x01(\t\x12\r\n\x05Label\x18\x02 \x01(\t\":\n\x08TNetData\x12.\n\x07Subnets\x18\x01 \x03(\x0b\x32\x1d.NKikimrNetClassifier.TSubnet\"\xce\x01\n\x14TNetClassifierConfig\x12H\n\rUpdaterConfig\x18\x01 \x01(\x0b\x32\x31.NKikimrNetClassifier.TNetClassifierUpdaterConfig\x12\x17\n\x0fNetDataFilePath\x18\x02 \x01(\t\x12#\n\x17\x43msConfigTimeoutSeconds\x18\x03 \x01(\r:\x02\x33\x30\x12.\n\"TimedCountersUpdateIntervalSeconds\x18\x04 \x01(\r:\x02\x31\x35\"v\n!TNetClassifierDistributableConfig\x12\x1d\n\x15LastUpdateDatetimeUTC\x18\x01 \x01(\t\x12\x1b\n\x13LastUpdateTimestamp\x18\x02 \x01(\x04\x12\x15\n\rPackedNetData\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.netclassifier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNETCLASSIFIERUPDATERCONFIG._serialized_start=62
  _TNETCLASSIFIERUPDATERCONFIG._serialized_end=317
  _TNETCLASSIFIERUPDATERCONFIG_EFORMAT._serialized_start=287
  _TNETCLASSIFIERUPDATERCONFIG_EFORMAT._serialized_end=317
  _TSUBNET._serialized_start=319
  _TSUBNET._serialized_end=357
  _TNETDATA._serialized_start=359
  _TNETDATA._serialized_end=417
  _TNETCLASSIFIERCONFIG._serialized_start=420
  _TNETCLASSIFIERCONFIG._serialized_end=626
  _TNETCLASSIFIERDISTRIBUTABLECONFIG._serialized_start=628
  _TNETCLASSIFIERDISTRIBUTABLECONFIG._serialized_end=746
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kqp_physical.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/kqp_physical.proto\x12\tNKqpProto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\x1a%ydb/public/api/protos/ydb_value.proto\"\x18\n\x16TKqpPhyExternalBinding\"\x92\x02\n\x16TKqpPhyInternalBinding\x12\x35\n\x04Type\x18\x01 \x01(\x0e\x32\'.NKqpProto.TKqpPhyInternalBinding.EType\"\xc0\x01\n\x05\x45Type\x12\x15\n\x11PARAM_UNSPECIFIED\x10\x00\x12\r\n\tPARAM_NOW\x10\x01\x12\x16\n\x12PARAM_CURRENT_DATE\x10\x02\x12\x1a\n\x16PARAM_CURRENT_DATETIME\x10\x03\x12\x1b\n\x17PARAM_CURRENT_TIMESTAMP\x10\x04\x12\x17\n\x13PARAM_RANDOM_NUMBER\x10\x05\x12\x10\n\x0cPARAM_RANDOM\x10\x06\x12\x15\n\x11PARAM_RANDOM_UUID\x10\x07\">\n\x16TKqpPhyTxResultBinding\x12\x0f\n\x07TxIndex\x18\x01 \x01(\r\x12\x13\n\x0bResultIndex\x18\x02 \x01(\r\"\xe5\x01\n\x13TKqpPhyParamBinding\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12<\n\x0f\x45xternalBinding\x18\x02 \x01(\x0b\x32!.NKqpProto.TKqpPhyExternalBindingH\x00\x12<\n\x0fTxResultBinding\x18\x03 \x01(\x0b\x32!.NKqpProto.TKqpPhyTxResultBindingH\x00\x12<\n\x0fInternalBinding\x18\x04 \x01(\x0b\x32!.NKqpProto.TKqpPhyInternalBindingH\x00\x42\x06\n\x04Type\"\\\n\x14TKqpPhyResultBinding\x12<\n\x0fTxResultBinding\x18\x01 \x01(\x0b\x32!.NKqpProto.TKqpPhyTxResultBindingH\x00\x42\x06\n\x04Type\")\n\rTKqpPhyColumn\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\"`\n\x0cTKqpPhyTable\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07OwnerId\x18\x02 \x01(\x04\x12\x0f\n\x07TableId\x18\x03 \x01(\x04\x12\x0f\n\x07SysView\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\x04\"&\n\x11TKqpPhyParamValue\x12\x11\n\tParamName\x18\x01 \x01(\t\"C\n\x18TKqpPhyParamElementValue\x12\x11\n\tParamName\x18\x01 \x01(\t\x12\x14\n\x0c\x45lementIndex\x18\x02 \x01(\r\"a\n\x13TKqpPhyLiteralValue\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue\"\xd9\x02\n\x0fTKqpPhyRowsList\x12-\n\x04Rows\x18\x01 \x03(\x0b\x32\x1f.NKqpProto.TKqpPhyRowsList.TRow\x1a|\n\x06TValue\x12\x32\n\nParamValue\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12\x36\n\x0cLiteralValue\x18\x02 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyLiteralValueH\x00\x42\x06\n\x04Kind\x1a\x98\x01\n\x04TRow\x12=\n\x07\x43olumns\x18\x01 \x03(\x0b\x32,.NKqpProto.TKqpPhyRowsList.TRow.ColumnsEntry\x1aQ\n\x0c\x43olumnsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.NKqpProto.TKqpPhyRowsList.TValue:\x02\x38\x01\"\xf4\x01\n\x0cTKqpPhyValue\x12\x32\n\nParamValue\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12@\n\x11ParamElementValue\x18\x02 \x01(\x0b\x32#.NKqpProto.TKqpPhyParamElementValueH\x00\x12.\n\x08RowsList\x18\x03 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyRowsListH\x00\x12\x36\n\x0cLiteralValue\x18\x04 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyLiteralValueH\x00\x42\x06\n\x04Kind\"O\n\x0fTKqpPhyKeyBound\x12\'\n\x06Values\x18\x01 \x03(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x13\n\x0bIsInclusive\x18\x02 \x01(\x08\"c\n\x0fTKqpPhyKeyRange\x12(\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyBound\x12&\n\x02To\x18\x02 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyBound\"\x96\x01\n\x12TKqpPhyOpReadRange\x12,\n\x08KeyRange\x18\x01 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyRange\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\x12\x14\n\x0cSkipNullKeys\x18\x04 \x03(\x08\"A\n\x13TKqpPhyOpUpsertRows\x12*\n\tRowsValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"A\n\x13TKqpPhyOpDeleteRows\x12*\n\tRowsValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"=\n\x0fTKqpPhyOpLookup\x12*\n\tKeysValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"\xef\x01\n\x17TKqpPhyOpReadOlapRanges\x12/\n\tKeyRanges\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValue\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\x12\x13\n\x0bOlapProgram\x18\x04 \x01(\x0c\x12!\n\x19OlapProgramParameterNames\x18\x05 \x03(\t\x12\x0e\n\x06Sorted\x18\x06 \x01(\x08\x12\x1d\n\nResultType\x18\x07 \x01(\x0b\x32\t.Ydb.Type\"\x84\x01\n\x13TKqpPhyOpReadRanges\x12/\n\tKeyRanges\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValue\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\"\xb3\x03\n\x15TKqpPhyTableOperation\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12)\n\x07\x43olumns\x18\x02 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyColumn\x12\x32\n\tReadRange\x18\x03 \x01(\x0b\x32\x1d.NKqpProto.TKqpPhyOpReadRangeH\x00\x12\x34\n\nUpsertRows\x18\x04 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpUpsertRowsH\x00\x12\x34\n\nDeleteRows\x18\x05 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpDeleteRowsH\x00\x12,\n\x06Lookup\x18\x06 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyOpLookupH\x00\x12;\n\rReadOlapRange\x18\x07 \x01(\x0b\x32\".NKqpProto.TKqpPhyOpReadOlapRangesH\x00\x12\x34\n\nReadRanges\x18\x08 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpReadRangesH\x00\x42\x06\n\x04Type\"\x13\n\x11TKqpPhyCnUnionAll\"\x0e\n\x0cTKqpPhyCnMap\"*\n\x14TKqpPhyCnHashShuffle\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\"\x14\n\x12TKqpPhyCnBroadcast\"\x13\n\x11TKqpPhyCnMapShard\"\x17\n\x15TKqpPhyCnShuffleShard\"\x11\n\x0fTKqpPhyCnResult\"\x10\n\x0eTKqpPhyCnValue\"6\n\x11TKqpPhySortColumn\x12\x0e\n\x06\x43olumn\x18\x01 \x01(\t\x12\x11\n\tAscending\x18\x02 \x01(\x08\"C\n\x0eTKqpPhyCnMerge\x12\x31\n\x0bSortColumns\x18\x01 \x03(\x0b\x32\x1c.NKqpProto.TKqpPhySortColumn\"\x90\x01\n\x15TKqpPhyCnStreamLookup\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12\x12\n\nKeyColumns\x18\x02 \x03(\t\x12\x0f\n\x07\x43olumns\x18\x03 \x03(\t\x12\x16\n\x0eLookupKeysType\x18\x04 \x01(\x0c\x12\x12\n\nResultType\x18\x05 \x01(\x0c\"\xca\x04\n\x11TKqpPhyConnection\x12\x12\n\nStageIndex\x18\x01 \x01(\r\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\r\x12\x12\n\nInputIndex\x18\r \x01(\r\x12\x30\n\x08UnionAll\x18\x03 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyCnUnionAllH\x00\x12&\n\x03Map\x18\x04 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyCnMapH\x00\x12\x36\n\x0bHashShuffle\x18\x05 \x01(\x0b\x32\x1f.NKqpProto.TKqpPhyCnHashShuffleH\x00\x12\x32\n\tBroadcast\x18\x06 \x01(\x0b\x32\x1d.NKqpProto.TKqpPhyCnBroadcastH\x00\x12\x30\n\x08MapShard\x18\x07 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyCnMapShardH\x00\x12\x38\n\x0cShuffleShard\x18\x08 \x01(\x0b\x32 .NKqpProto.TKqpPhyCnShuffleShardH\x00\x12,\n\x06Result\x18\t \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyCnResultH\x00\x12*\n\x05Value\x18\n \x01(\x0b\x32\x19.NKqpProto.TKqpPhyCnValueH\x00\x12*\n\x05Merge\x18\x0b \x01(\x0b\x32\x19.NKqpProto.TKqpPhyCnMergeH\x00\x12\x38\n\x0cStreamLookup\x18\x0c \x01(\x0b\x32 .NKqpProto.TKqpPhyCnStreamLookupH\x00\x42\x06\n\x04Type\"\xbb\x02\n\x14TKqpReadRangesSource\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12)\n\x07\x43olumns\x18\x02 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyColumn\x12+\n\nItemsLimit\x18\x03 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x04 \x01(\x08\x12\x0e\n\x06Sorted\x18\x05 \x01(\x08\x12.\n\x06Ranges\x18\x06 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12.\n\x08KeyRange\x18\x07 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyRangeH\x00\x12\x14\n\x0cSkipNullKeys\x18\x08 \x03(\tB\x0c\n\nRangesExpr\"e\n\nTKqpSource\x12\x12\n\nInputIndex\x18\x01 \x01(\r\x12;\n\x10ReadRangesSource\x18\x03 \x01(\x0b\x32\x1f.NKqpProto.TKqpReadRangesSourceH\x00\x42\x06\n\x04Type\"\xb2\x02\n\x0cTKqpPhyStage\x12(\n\x07Program\x18\x01 \x01(\x0b\x32\x17.NYql.NDqProto.TProgram\x12\x19\n\x11ProgramParameters\x18\x02 \x03(\t\x12\x12\n\nProgramAst\x18\x03 \x01(\t\x12,\n\x06Inputs\x18\x04 \x03(\x0b\x32\x1c.NKqpProto.TKqpPhyConnection\x12\x14\n\x0cOutputsCount\x18\x05 \x01(\r\x12\x32\n\x08TableOps\x18\x06 \x03(\x0b\x32 .NKqpProto.TKqpPhyTableOperation\x12\x16\n\x0eIsEffectsStage\x18\x07 \x01(\x08\x12\x11\n\tStageGuid\x18\x08 \x01(\t\x12&\n\x07Sources\x18\t \x03(\x0b\x32\x15.NKqpProto.TKqpSource\"\x91\x01\n\rTKqpPhyResult\x12\x30\n\nConnection\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyConnection\x12\'\n\x08ItemType\x18\x02 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12\x10\n\x08IsStream\x18\x03 \x01(\x08\x12\x13\n\x0b\x43olumnHints\x18\x04 \x03(\t\"\xc3\x02\n\tTKqpPhyTx\x12(\n\x04Type\x18\x01 \x01(\x0e\x32\x1a.NKqpProto.TKqpPhyTx.EType\x12\'\n\x06Stages\x18\x02 \x03(\x0b\x32\x17.NKqpProto.TKqpPhyStage\x12)\n\x07Results\x18\x03 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyResult\x12\x35\n\rParamBindings\x18\x04 \x03(\x0b\x32\x1e.NKqpProto.TKqpPhyParamBinding\x12\x0c\n\x04Plan\x18\x05 \x01(\t\x12\x12\n\nHasEffects\x18\x06 \x01(\x08\"_\n\x05\x45Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_COMPUTE\x10\x01\x12\r\n\tTYPE_DATA\x10\x02\x12\r\n\tTYPE_SCAN\x10\x03\x12\x10\n\x0cTYPE_GENERIC\x10\x04\"\xa9\x01\n\rTKqpTableInfo\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpTableInfo.TId\x12\x11\n\tTableName\x18\x02 \x01(\t\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\x12\x16\n\x0eHasIndexTables\x18\x04 \x01(\x08\x1a\'\n\x03TId\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"\x8d\x01\n\x0bTKqpTableOp\x12\x32\n\x08Position\x18\x01 \x01(\x0b\x32 .NKqpProto.TKqpTableOp.TPosition\x12\r\n\x05Table\x18\x02 \x01(\t\x12\x11\n\tOperation\x18\x03 \x01(\r\x1a(\n\tTPosition\x12\x0b\n\x03Row\x18\x01 \x01(\r\x12\x0e\n\x06\x43olumn\x18\x02 \x01(\r\"\x93\x03\n\x0cTKqpPhyQuery\x12+\n\x04Type\x18\x01 \x01(\x0e\x32\x1d.NKqpProto.TKqpPhyQuery.EType\x12*\n\x0cTransactions\x18\x02 \x03(\x0b\x32\x14.NKqpProto.TKqpPhyTx\x12\x37\n\x0eResultBindings\x18\x04 \x03(\x0b\x32\x1f.NKqpProto.TKqpPhyResultBinding\x12\x11\n\tQueryPlan\x18\x05 \x01(\t\x12\x10\n\x08QueryAst\x18\x06 \x01(\t\x12(\n\x08TableOps\x18\x07 \x03(\x0b\x32\x16.NKqpProto.TKqpTableOp\x12,\n\nTableInfos\x18\x08 \x03(\x0b\x32\x18.NKqpProto.TKqpTableInfo\x12!\n\x19HasUncommittedChangesRead\x18\t \x01(\x08\"K\n\x05\x45Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tTYPE_DATA\x10\x01\x12\r\n\tTYPE_SCAN\x10\x02\x12\x0e\n\nTYPE_QUERY\x10\x03J\x04\x08\x03\x10\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kqp_physical_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._options = None
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_options = b'8\001'
  _TKQPPHYEXTERNALBINDING._serialized_start=174
  _TKQPPHYEXTERNALBINDING._serialized_end=198
  _TKQPPHYINTERNALBINDING._serialized_start=201
  _TKQPPHYINTERNALBINDING._serialized_end=475
  _TKQPPHYINTERNALBINDING_ETYPE._serialized_start=283
  _TKQPPHYINTERNALBINDING_ETYPE._serialized_end=475
  _TKQPPHYTXRESULTBINDING._serialized_start=477
  _TKQPPHYTXRESULTBINDING._serialized_end=539
  _TKQPPHYPARAMBINDING._serialized_start=542
  _TKQPPHYPARAMBINDING._serialized_end=771
  _TKQPPHYRESULTBINDING._serialized_start=773
  _TKQPPHYRESULTBINDING._serialized_end=865
  _TKQPPHYCOLUMN._serialized_start=867
  _TKQPPHYCOLUMN._serialized_end=908
  _TKQPPHYTABLE._serialized_start=910
  _TKQPPHYTABLE._serialized_end=1006
  _TKQPPHYPARAMVALUE._serialized_start=1008
  _TKQPPHYPARAMVALUE._serialized_end=1046
  _TKQPPHYPARAMELEMENTVALUE._serialized_start=1048
  _TKQPPHYPARAMELEMENTVALUE._serialized_end=1115
  _TKQPPHYLITERALVALUE._serialized_start=1117
  _TKQPPHYLITERALVALUE._serialized_end=1214
  _TKQPPHYROWSLIST._serialized_start=1217
  _TKQPPHYROWSLIST._serialized_end=1562
  _TKQPPHYROWSLIST_TVALUE._serialized_start=1283
  _TKQPPHYROWSLIST_TVALUE._serialized_end=1407
  _TKQPPHYROWSLIST_TROW._serialized_start=1410
  _TKQPPHYROWSLIST_TROW._serialized_end=1562
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_start=1481
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_end=1562
  _TKQPPHYVALUE._serialized_start=1565
  _TKQPPHYVALUE._serialized_end=1809
  _TKQPPHYKEYBOUND._serialized_start=1811
  _TKQPPHYKEYBOUND._serialized_end=1890
  _TKQPPHYKEYRANGE._serialized_start=1892
  _TKQPPHYKEYRANGE._serialized_end=1991
  _TKQPPHYOPREADRANGE._serialized_start=1994
  _TKQPPHYOPREADRANGE._serialized_end=2144
  _TKQPPHYOPUPSERTROWS._serialized_start=2146
  _TKQPPHYOPUPSERTROWS._serialized_end=2211
  _TKQPPHYOPDELETEROWS._serialized_start=2213
  _TKQPPHYOPDELETEROWS._serialized_end=2278
  _TKQPPHYOPLOOKUP._serialized_start=2280
  _TKQPPHYOPLOOKUP._serialized_end=2341
  _TKQPPHYOPREADOLAPRANGES._serialized_start=2344
  _TKQPPHYOPREADOLAPRANGES._serialized_end=2583
  _TKQPPHYOPREADRANGES._serialized_start=2586
  _TKQPPHYOPREADRANGES._serialized_end=2718
  _TKQPPHYTABLEOPERATION._serialized_start=2721
  _TKQPPHYTABLEOPERATION._serialized_end=3156
  _TKQPPHYCNUNIONALL._serialized_start=3158
  _TKQPPHYCNUNIONALL._serialized_end=3177
  _TKQPPHYCNMAP._serialized_start=3179
  _TKQPPHYCNMAP._serialized_end=3193
  _TKQPPHYCNHASHSHUFFLE._serialized_start=3195
  _TKQPPHYCNHASHSHUFFLE._serialized_end=3237
  _TKQPPHYCNBROADCAST._serialized_start=3239
  _TKQPPHYCNBROADCAST._serialized_end=3259
  _TKQPPHYCNMAPSHARD._serialized_start=3261
  _TKQPPHYCNMAPSHARD._serialized_end=3280
  _TKQPPHYCNSHUFFLESHARD._serialized_start=3282
  _TKQPPHYCNSHUFFLESHARD._serialized_end=3305
  _TKQPPHYCNRESULT._serialized_start=3307
  _TKQPPHYCNRESULT._serialized_end=3324
  _TKQPPHYCNVALUE._serialized_start=3326
  _TKQPPHYCNVALUE._serialized_end=3342
  _TKQPPHYSORTCOLUMN._serialized_start=3344
  _TKQPPHYSORTCOLUMN._serialized_end=3398
  _TKQPPHYCNMERGE._serialized_start=3400
  _TKQPPHYCNMERGE._serialized_end=3467
  _TKQPPHYCNSTREAMLOOKUP._serialized_start=3470
  _TKQPPHYCNSTREAMLOOKUP._serialized_end=3614
  _TKQPPHYCONNECTION._serialized_start=3617
  _TKQPPHYCONNECTION._serialized_end=4203
  _TKQPREADRANGESSOURCE._serialized_start=4206
  _TKQPREADRANGESSOURCE._serialized_end=4521
  _TKQPSOURCE._serialized_start=4523
  _TKQPSOURCE._serialized_end=4624
  _TKQPPHYSTAGE._serialized_start=4627
  _TKQPPHYSTAGE._serialized_end=4933
  _TKQPPHYRESULT._serialized_start=4936
  _TKQPPHYRESULT._serialized_end=5081
  _TKQPPHYTX._serialized_start=5084
  _TKQPPHYTX._serialized_end=5407
  _TKQPPHYTX_ETYPE._serialized_start=5312
  _TKQPPHYTX_ETYPE._serialized_end=5407
  _TKQPTABLEINFO._serialized_start=5410
  _TKQPTABLEINFO._serialized_end=5579
  _TKQPTABLEINFO_TID._serialized_start=5540
  _TKQPTABLEINFO_TID._serialized_end=5579
  _TKQPTABLEOP._serialized_start=5582
  _TKQPTABLEOP._serialized_end=5723
  _TKQPTABLEOP_TPOSITION._serialized_start=5683
  _TKQPTABLEOP_TPOSITION._serialized_end=5723
  _TKQPPHYQUERY._serialized_start=5726
  _TKQPPHYQUERY._serialized_end=6129
  _TKQPPHYQUERY_ETYPE._serialized_start=6048
  _TKQPPHYQUERY_ETYPE._serialized_end=6123
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kesus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.public.api.protos import ydb_coordination_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__coordination__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/kesus.proto\x12\x0cNKikimrKesus\x1a&library/cpp/actors/protos/actors.proto\x1a,ydb/public/api/protos/ydb_coordination.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"a\n\x0bTKesusError\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"*\n\x0fTEvDummyRequest\x12\x17\n\x0fUseTransactions\x18\x01 \x01(\x08\"\x12\n\x10TEvDummyResponse\"e\n\x0cTEvSetConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12(\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x0c\n\x04Path\x18\x04 \x01(\t\"^\n\x12TEvSetConfigResult\x12(\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\"\x0e\n\x0cTEvGetConfig\"]\n\x12TEvGetConfigResult\x12(\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x0c\n\x04Path\x18\x03 \x01(\t\"\'\n\x12TEvDescribeProxies\x12\x11\n\tKesusPath\x18\x01 \x01(\t\"\xd1\x01\n\x18TEvDescribeProxiesResult\x12I\n\x07Proxies\x18\x01 \x03(\x0b\x32\x38.NKikimrKesus.TEvDescribeProxiesResult.TProxyDescription\x1aj\n\x11TProxyDescription\x12\'\n\x07\x41\x63torID\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x18\n\x10\x41ttachedSessions\x18\x03 \x03(\x04\"(\n\x13TEvDescribeSessions\x12\x11\n\tKesusPath\x18\x01 \x01(\t\"\xed\x01\n\x19TEvDescribeSessionsResult\x12M\n\x08Sessions\x18\x01 \x03(\x0b\x32;.NKikimrKesus.TEvDescribeSessionsResult.TSessionDescription\x1a\x80\x01\n\x13TSessionDescription\x12\x11\n\tSessionId\x18\x01 \x01(\x04\x12\x15\n\rTimeoutMillis\x18\x02 \x01(\x04\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12*\n\nOwnerProxy\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\xba\x01\n\x14TEvDescribeSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x15\n\rIncludeOwners\x18\x05 \x01(\x08\x12\x16\n\x0eIncludeWaiters\x18\x06 \x01(\x08\x12\x11\n\tWatchData\x18\x07 \x01(\x08\x12\x13\n\x0bWatchOwners\x18\x08 \x01(\x08\"\xb9\x01\n\x1aTEvDescribeSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x44\n\x14SemaphoreDescription\x18\x03 \x01(\x0b\x32&.Ydb.Coordination.SemaphoreDescription\x12\x12\n\nWatchAdded\x18\x04 \x01(\x08\"b\n\x1bTEvDescribeSemaphoreChanged\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12\x13\n\x0b\x44\x61taChanged\x18\x02 \x01(\x08\x12\x15\n\rOwnersChanged\x18\x03 \x01(\x08\"~\n\x12TEvCreateSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\r\n\x05Limit\x18\x05 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x06 \x01(\x0c\"]\n\x18TEvCreateSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"o\n\x12TEvUpdateSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\"]\n\x18TEvUpdateSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"p\n\x12TEvDeleteSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\r\n\x05\x46orce\x18\x05 \x01(\x08\"]\n\x18TEvDeleteSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\">\n\x10TEvRegisterProxy\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\"[\n\x16TEvRegisterProxyResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"@\n\x12TEvUnregisterProxy\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\"]\n\x18TEvUnregisterProxyResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xa3\x01\n\x10TEvAttachSession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x15\n\rTimeoutMillis\x18\x04 \x01(\x04\x12\x13\n\x0b\x44\x65scription\x18\x05 \x01(\t\x12\r\n\x05SeqNo\x18\x06 \x01(\x04\x12\x15\n\rProtectionKey\x18\x07 \x01(\x0c\"n\n\x16TEvAttachSessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"Q\n\x10TEvDetachSession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"[\n\x16TEvDetachSessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"R\n\x11TEvDestroySession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"\\\n\x17TEvDestroySessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xa9\x01\n\x13TEvAcquireSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x15\n\rTimeoutMillis\x18\x05 \x01(\x04\x12\r\n\x05\x43ount\x18\x06 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x07 \x01(\x0c\x12\x11\n\tEphemeral\x18\x08 \x01(\x08\"5\n\x1aTEvAcquireSemaphorePending\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\"p\n\x19TEvAcquireSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x10\n\x08\x41\x63quired\x18\x03 \x01(\x08\"b\n\x13TEvReleaseSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\"p\n\x19TEvReleaseSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x10\n\x08Released\x18\x03 \x01(\x08\"*\n\x0fTEvProxyExpired\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\"&\n\x11TEvSessionExpired\x12\x11\n\tSessionId\x18\x01 \x01(\x04\">\n\x10TEvSessionStolen\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12\x11\n\tSessionId\x18\x02 \x01(\x04\"\x94\x05\n\x11TAccountingConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x16\n\x0eReportPeriodMs\x18\x02 \x01(\x04\x12\x17\n\x0f\x41\x63\x63ountPeriodMs\x18\x03 \x01(\x04\x12\x18\n\x10\x43ollectPeriodSec\x18\x04 \x01(\x04\x12!\n\x19ProvisionedUnitsPerSecond\x18\x05 \x01(\x01\x12\x1e\n\x16ProvisionedCoefficient\x18\x06 \x01(\x01\x12\x1c\n\x14OvershootCoefficient\x18\x07 \x01(\x01\x12<\n\x0bProvisioned\x18\x08 \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x12\x39\n\x08OnDemand\x18\t \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x12:\n\tOvershoot\x18\n \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x1a\x8c\x02\n\x07TMetric\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x42illingPeriodSec\x18\x02 \x01(\x04\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x0e\n\x06Schema\x18\x05 \x01(\t\x12\x0f\n\x07\x43loudId\x18\x06 \x01(\t\x12\x10\n\x08\x46olderId\x18\x07 \x01(\t\x12\x12\n\nResourceId\x18\x08 \x01(\t\x12\x10\n\x08SourceId\x18\t \x01(\t\x12?\n\x04Tags\x18\n \x03(\x0b\x32\x31.NKikimrKesus.TAccountingConfig.TMetric.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x02\n\x1eTHierarchicalDRRResourceConfig\x12\x19\n\x11MaxUnitsPerSecond\x18\x03 \x01(\x01\x12\x1f\n\x17MaxBurstSizeCoefficient\x18\x04 \x01(\x01\x12\x0e\n\x06Weight\x18\x05 \x01(\r\x12\x1b\n\x13PrefetchCoefficient\x18\x06 \x01(\x01\x12\x19\n\x11PrefetchWatermark\x18\x07 \x01(\x01\x12R\n\rSpeedSettings\x18\x01 \x01(\x0b\x32;.NKikimrKesus.THierarchicalDRRResourceConfig.TSpeedSettings\x1a+\n\x0eTSpeedSettings\x12\x19\n\x11MaxUnitsPerSecond\x18\x01 \x01(\x01\"\xf0\x01\n\x18TStreamingQuoterResource\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\x12T\n\x1cHierarhicalDRRResourceConfig\x18\x03 \x01(\x0b\x32,.NKikimrKesus.THierarchicalDRRResourceConfigH\x00\x12\x39\n\x10\x41\x63\x63ountingConfig\x18\x04 \x01(\x0b\x32\x1f.NKikimrKesus.TAccountingConfigB\x19\n\x17\x41lgorithmSpecificConfig\"[\n\x1aTEvDescribeQuoterResources\x12\x13\n\x0bResourceIds\x18\x01 \x03(\x04\x12\x15\n\rResourcePaths\x18\x02 \x03(\t\x12\x11\n\tRecursive\x18\x03 \x01(\x08\"\x87\x01\n TEvDescribeQuoterResourcesResult\x12\x39\n\tResources\x18\x02 \x03(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\x12(\n\x05\x45rror\x18\x03 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"P\n\x14TEvAddQuoterResource\x12\x38\n\x08Resource\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"Z\n\x1aTEvAddQuoterResourceResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"S\n\x17TEvUpdateQuoterResource\x12\x38\n\x08Resource\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"]\n\x1dTEvUpdateQuoterResourceResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"C\n\x17TEvDeleteQuoterResource\x12\x12\n\nResourceId\x18\x03 \x01(\x04\x12\x14\n\x0cResourcePath\x18\x04 \x01(\t\"I\n\x1dTEvDeleteQuoterResourceResult\x12(\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xf2\x01\n\x17TEvSubscribeOnResources\x12O\n\tResources\x18\x01 \x03(\x0b\x32<.NKikimrKesus.TEvSubscribeOnResources.TResourceSubscribeInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1a]\n\x16TResourceSubscribeInfo\x12\x14\n\x0cResourcePath\x18\x01 \x01(\t\x12\x16\n\x0eStartConsuming\x18\x02 \x01(\x08\x12\x15\n\rInitialAmount\x18\x03 \x01(\x01\"\x91\x02\n\x1dTEvSubscribeOnResourcesResult\x12U\n\x07Results\x18\x01 \x03(\x0b\x32\x44.NKikimrKesus.TEvSubscribeOnResourcesResult.TResourceSubscribeResult\x1a\x98\x01\n\x18TResourceSubscribeResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12>\n\x0e\x45\x66\x66\x65\x63tiveProps\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"\xe0\x01\n\x19TEvUpdateConsumptionState\x12L\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x35.NKikimrKesus.TEvUpdateConsumptionState.TResourceInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aL\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x17\n\x0f\x43onsumeResource\x18\x02 \x01(\x08\x12\x0e\n\x06\x41mount\x18\x03 \x01(\x01\"\x1e\n\x1cTEvUpdateConsumptionStateAck\"\x8d\x02\n\x15TEvResourcesAllocated\x12H\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x31.NKikimrKesus.TEvResourcesAllocated.TResourceInfo\x1a\xa9\x01\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x01\x12>\n\x0e\x45\x66\x66\x65\x63tiveProps\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\x12\x34\n\x11StateNotification\x18\x04 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\x1a\n\x18TEvResourcesAllocatedAck\"\x1e\n\x1cTEvGetQuoterResourceCounters\"\xc0\x01\n\"TEvGetQuoterResourceCountersResult\x12\\\n\x10ResourceCounters\x18\x01 \x03(\x0b\x32\x42.NKikimrKesus.TEvGetQuoterResourceCountersResult.TResourceCounters\x1a<\n\x11TResourceCounters\x12\x14\n\x0cResourcePath\x18\x01 \x01(\t\x12\x11\n\tAllocated\x18\x02 \x01(\x04\"\xe0\x01\n\x13TEvAccountResources\x12\x46\n\rResourcesInfo\x18\x01 \x03(\x0b\x32/.NKikimrKesus.TEvAccountResources.TResourceInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aX\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x0f\n\x07StartUs\x18\x02 \x01(\x04\x12\x12\n\nIntervalUs\x18\x03 \x01(\x04\x12\x0e\n\x06\x41mount\x18\x04 \x03(\x01\"\xd2\x01\n\x16TEvAccountResourcesAck\x12I\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x32.NKikimrKesus.TEvAccountResourcesAck.TResourceInfo\x1am\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x12\n\nAcceptedUs\x18\x02 \x01(\x04\x12\x34\n\x11StateNotification\x18\x04 \x01(\x0b\x32\x19.NKikimrKesus.TKesusErrorB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kesus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._options = None
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_options = b'8\001'
  _TKESUSERROR._serialized_start=224
  _TKESUSERROR._serialized_end=321
  _TEVDUMMYREQUEST._serialized_start=323
  _TEVDUMMYREQUEST._serialized_end=365
  _TEVDUMMYRESPONSE._serialized_start=367
  _TEVDUMMYRESPONSE._serialized_end=385
  _TEVSETCONFIG._serialized_start=387
  _TEVSETCONFIG._serialized_end=488
  _TEVSETCONFIGRESULT._serialized_start=490
  _TEVSETCONFIGRESULT._serialized_end=584
  _TEVGETCONFIG._serialized_start=586
  _TEVGETCONFIG._serialized_end=600
  _TEVGETCONFIGRESULT._serialized_start=602
  _TEVGETCONFIGRESULT._serialized_end=695
  _TEVDESCRIBEPROXIES._serialized_start=697
  _TEVDESCRIBEPROXIES._serialized_end=736
  _TEVDESCRIBEPROXIESRESULT._serialized_start=739
  _TEVDESCRIBEPROXIESRESULT._serialized_end=948
  _TEVDESCRIBEPROXIESRESULT_TPROXYDESCRIPTION._serialized_start=842
  _TEVDESCRIBEPROXIESRESULT_TPROXYDESCRIPTION._serialized_end=948
  _TEVDESCRIBESESSIONS._serialized_start=950
  _TEVDESCRIBESESSIONS._serialized_end=990
  _TEVDESCRIBESESSIONSRESULT._serialized_start=993
  _TEVDESCRIBESESSIONSRESULT._serialized_end=1230
  _TEVDESCRIBESESSIONSRESULT_TSESSIONDESCRIPTION._serialized_start=1102
  _TEVDESCRIBESESSIONSRESULT_TSESSIONDESCRIPTION._serialized_end=1230
  _TEVDESCRIBESEMAPHORE._serialized_start=1233
  _TEVDESCRIBESEMAPHORE._serialized_end=1419
  _TEVDESCRIBESEMAPHORERESULT._serialized_start=1422
  _TEVDESCRIBESEMAPHORERESULT._serialized_end=1607
  _TEVDESCRIBESEMAPHORECHANGED._serialized_start=1609
  _TEVDESCRIBESEMAPHORECHANGED._serialized_end=1707
  _TEVCREATESEMAPHORE._serialized_start=1709
  _TEVCREATESEMAPHORE._serialized_end=1835
  _TEVCREATESEMAPHORERESULT._serialized_start=1837
  _TEVCREATESEMAPHORERESULT._serialized_end=1930
  _TEVUPDATESEMAPHORE._serialized_start=1932
  _TEVUPDATESEMAPHORE._serialized_end=2043
  _TEVUPDATESEMAPHORERESULT._serialized_start=2045
  _TEVUPDATESEMAPHORERESULT._serialized_end=2138
  _TEVDELETESEMAPHORE._serialized_start=2140
  _TEVDELETESEMAPHORE._serialized_end=2252
  _TEVDELETESEMAPHORERESULT._serialized_start=2254
  _TEVDELETESEMAPHORERESULT._serialized_end=2347
  _TEVREGISTERPROXY._serialized_start=2349
  _TEVREGISTERPROXY._serialized_end=2411
  _TEVREGISTERPROXYRESULT._serialized_start=2413
  _TEVREGISTERPROXYRESULT._serialized_end=2504
  _TEVUNREGISTERPROXY._serialized_start=2506
  _TEVUNREGISTERPROXY._serialized_end=2570
  _TEVUNREGISTERPROXYRESULT._serialized_start=2572
  _TEVUNREGISTERPROXYRESULT._serialized_end=2665
  _TEVATTACHSESSION._serialized_start=2668
  _TEVATTACHSESSION._serialized_end=2831
  _TEVATTACHSESSIONRESULT._serialized_start=2833
  _TEVATTACHSESSIONRESULT._serialized_end=2943
  _TEVDETACHSESSION._serialized_start=2945
  _TEVDETACHSESSION._serialized_end=3026
  _TEVDETACHSESSIONRESULT._serialized_start=3028
  _TEVDETACHSESSIONRESULT._serialized_end=3119
  _TEVDESTROYSESSION._serialized_start=3121
  _TEVDESTROYSESSION._serialized_end=3203
  _TEVDESTROYSESSIONRESULT._serialized_start=3205
  _TEVDESTROYSESSIONRESULT._serialized_end=3297
  _TEVACQUIRESEMAPHORE._serialized_start=3300
  _TEVACQUIRESEMAPHORE._serialized_end=3469
  _TEVACQUIRESEMAPHOREPENDING._serialized_start=3471
  _TEVACQUIRESEMAPHOREPENDING._serialized_end=3524
  _TEVACQUIRESEMAPHORERESULT._serialized_start=3526
  _TEVACQUIRESEMAPHORERESULT._serialized_end=3638
  _TEVRELEASESEMAPHORE._serialized_start=3640
  _TEVRELEASESEMAPHORE._serialized_end=3738
  _TEVRELEASESEMAPHORERESULT._serialized_start=3740
  _TEVRELEASESEMAPHORERESULT._serialized_end=3852
  _TEVPROXYEXPIRED._serialized_start=3854
  _TEVPROXYEXPIRED._serialized_end=3896
  _TEVSESSIONEXPIRED._serialized_start=3898
  _TEVSESSIONEXPIRED._serialized_end=3936
  _TEVSESSIONSTOLEN._serialized_start=3938
  _TEVSESSIONSTOLEN._serialized_end=4000
  _TACCOUNTINGCONFIG._serialized_start=4003
  _TACCOUNTINGCONFIG._serialized_end=4663
  _TACCOUNTINGCONFIG_TMETRIC._serialized_start=4395
  _TACCOUNTINGCONFIG_TMETRIC._serialized_end=4663
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_start=4620
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_end=4663
  _THIERARCHICALDRRRESOURCECONFIG._serialized_start=4666
  _THIERARCHICALDRRRESOURCECONFIG._serialized_end=4959
  _THIERARCHICALDRRRESOURCECONFIG_TSPEEDSETTINGS._serialized_start=4916
  _THIERARCHICALDRRRESOURCECONFIG_TSPEEDSETTINGS._serialized_end=4959
  _TSTREAMINGQUOTERRESOURCE._serialized_start=4962
  _TSTREAMINGQUOTERRESOURCE._serialized_end=5202
  _TEVDESCRIBEQUOTERRESOURCES._serialized_start=5204
  _TEVDESCRIBEQUOTERRESOURCES._serialized_end=5295
  _TEVDESCRIBEQUOTERRESOURCESRESULT._serialized_start=5298
  _TEVDESCRIBEQUOTERRESOURCESRESULT._serialized_end=5433
  _TEVADDQUOTERRESOURCE._serialized_start=5435
  _TEVADDQUOTERRESOURCE._serialized_end=5515
  _TEVADDQUOTERRESOURCERESULT._serialized_start=5517
  _TEVADDQUOTERRESOURCERESULT._serialized_end=5607
  _TEVUPDATEQUOTERRESOURCE._serialized_start=5609
  _TEVUPDATEQUOTERRESOURCE._serialized_end=5692
  _TEVUPDATEQUOTERRESOURCERESULT._serialized_start=5694
  _TEVUPDATEQUOTERRESOURCERESULT._serialized_end=5787
  _TEVDELETEQUOTERRESOURCE._serialized_start=5789
  _TEVDELETEQUOTERRESOURCE._serialized_end=5856
  _TEVDELETEQUOTERRESOURCERESULT._serialized_start=5858
  _TEVDELETEQUOTERRESOURCERESULT._serialized_end=5931
  _TEVSUBSCRIBEONRESOURCES._serialized_start=5934
  _TEVSUBSCRIBEONRESOURCES._serialized_end=6176
  _TEVSUBSCRIBEONRESOURCES_TRESOURCESUBSCRIBEINFO._serialized_start=6083
  _TEVSUBSCRIBEONRESOURCES_TRESOURCESUBSCRIBEINFO._serialized_end=6176
  _TEVSUBSCRIBEONRESOURCESRESULT._serialized_start=6179
  _TEVSUBSCRIBEONRESOURCESRESULT._serialized_end=6452
  _TEVSUBSCRIBEONRESOURCESRESULT_TRESOURCESUBSCRIBERESULT._serialized_start=6300
  _TEVSUBSCRIBEONRESOURCESRESULT_TRESOURCESUBSCRIBERESULT._serialized_end=6452
  _TEVUPDATECONSUMPTIONSTATE._serialized_start=6455
  _TEVUPDATECONSUMPTIONSTATE._serialized_end=6679
  _TEVUPDATECONSUMPTIONSTATE_TRESOURCEINFO._serialized_start=6603
  _TEVUPDATECONSUMPTIONSTATE_TRESOURCEINFO._serialized_end=6679
  _TEVUPDATECONSUMPTIONSTATEACK._serialized_start=6681
  _TEVUPDATECONSUMPTIONSTATEACK._serialized_end=6711
  _TEVRESOURCESALLOCATED._serialized_start=6714
  _TEVRESOURCESALLOCATED._serialized_end=6983
  _TEVRESOURCESALLOCATED_TRESOURCEINFO._serialized_start=6814
  _TEVRESOURCESALLOCATED_TRESOURCEINFO._serialized_end=6983
  _TEVRESOURCESALLOCATEDACK._serialized_start=6985
  _TEVRESOURCESALLOCATEDACK._serialized_end=7011
  _TEVGETQUOTERRESOURCECOUNTERS._serialized_start=7013
  _TEVGETQUOTERRESOURCECOUNTERS._serialized_end=7043
  _TEVGETQUOTERRESOURCECOUNTERSRESULT._serialized_start=7046
  _TEVGETQUOTERRESOURCECOUNTERSRESULT._serialized_end=7238
  _TEVGETQUOTERRESOURCECOUNTERSRESULT_TRESOURCECOUNTERS._serialized_start=7178
  _TEVGETQUOTERRESOURCECOUNTERSRESULT_TRESOURCECOUNTERS._serialized_end=7238
  _TEVACCOUNTRESOURCES._serialized_start=7241
  _TEVACCOUNTRESOURCES._serialized_end=7465
  _TEVACCOUNTRESOURCES_TRESOURCEINFO._serialized_start=7377
  _TEVACCOUNTRESOURCES_TRESOURCEINFO._serialized_end=7465
  _TEVACCOUNTRESOURCESACK._serialized_start=7468
  _TEVACCOUNTRESOURCESACK._serialized_end=7678
  _TEVACCOUNTRESOURCESACK_TRESOURCEINFO._serialized_start=7569
  _TEVACCOUNTRESOURCESACK_TRESOURCEINFO._serialized_end=7678
# @@protoc_insertion_point(module_scope)
